| Title: | This tests the functionality of developing an R Data Package |
|---|---|
| Description: | This package provides each round of Household Pulse Survey data and respective codebooks in an easily accessible manner. Raw data sets of Household Pulse Survey data [Public Use Files] can be accessed at the US Census Website. |
| Authors: | Prasad Bhoite [aut, cre] (ORCID: <https://orcid.org/0000-0003-2548-0066>), Christopher Clark [aut], Krupa Patel [aut] |
| Maintainer: | Prasad Bhoite <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 0.0.0.9000 |
| Built: | 2026-05-11 09:11:29 UTC |
| Source: | https://github.com/christophernclark/hpsrn |
Load the data by week number
load_data_week_number(week)load_data_week_number(week)
week |
Week number |
data
## Not run: Example 1: Import week 1 data: load_data_week_number(1) ## End(Not run)## Not run: Example 1: Import week 1 data: load_data_week_number(1) ## End(Not run)